.. These are examples of badges you might want to add to your README:
   please update the URLs accordingly

    .. image:: https://api.cirrus-ci.com/github/<USER>/oracowl.svg?branch=main
        :alt: Built Status
        :target: https://cirrus-ci.com/github/<USER>/oracowl
    .. image:: https://readthedocs.org/projects/oracowl/badge/?version=latest
        :alt: ReadTheDocs
        :target: https://oracowl.readthedocs.io/en/stable/
    .. image:: https://img.shields.io/coveralls/github/<USER>/oracowl/main.svg
        :alt: Coveralls
        :target: https://coveralls.io/r/<USER>/oracowl
    .. image:: https://img.shields.io/pypi/v/oracowl.svg
        :alt: PyPI-Server
        :target: https://pypi.org/project/oracowl/
    .. image:: https://img.shields.io/conda/vn/conda-forge/oracowl.svg
        :alt: Conda-Forge
        :target: https://anaconda.org/conda-forge/oracowl
    .. image:: https://pepy.tech/badge/oracowl/month
        :alt: Monthly Downloads
        :target: https://pepy.tech/project/oracowl
    .. image:: https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Twitter
        :alt: Twitter
        :target: https://twitter.com/oracowl

.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/

|

=======
Oracowl
=======


    Oracowl is a simple Python package that provides a set of tools for astrophotographers for planning their imaging nights.


This library was initially developed to support the mobile and web application Oracowl that was born as a personal project to support other astrophotagraphers and to give them a free tool without ads or any other kind of monetization.
It's based on the great pyephem library to make the calculations and it's designed to be easy to use and to be integrated with other tools or to build APIs on top of it.


.. _pyscaffold-notes:

Note
====

I'm by no means a professional astronomer, but I do love to take pictures of the night sky. I'm always looking for ways to improve my images and to make the process of planning my imaging nights easier. This is why I created Oracowl. I hope you find it useful and if you have any suggestions or want to contribute, please feel free to do so.
